igraph: A library for creating and manipulating graphs
======================================================

Description
-----------

igraph is a library for creating and manipulating graphs. It is intended
to be as powerful (ie. fast) as possible to enable the analysis of large
graphs.

License
-------

GPL version 2


Upstream Contact
----------------

http://igraph.org/c/

Dependencies
------------

-  GMP/MPIR
-  libxml2, but this is not shipped with Sage, so the user has to
   install
   libxml2-dev from her distro.


Special Update/Build Instructions
---------------------------------
